"use strict";
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const TemplateResult_1 = require("./TemplateResult");
const ntriples = __importStar(require("./syntax/ntriples"));
class NQuadsStrategy extends TemplateResult_1.SerializationStrategy {
    evaluateDataset(dataset, options) {
        const [first, ...rest] = dataset;
        let firstQuadString = { value: '', prefixes: [] };
        if (first) {
            firstQuadString = this.evaluateQuad(first, options);
        }
        return rest.reduce((result, quad) => {
            const nextQuad = this.evaluateQuad(quad, options);
            return {
                value: `${result.value}\n${nextQuad.value}`,
                prefixes: result.prefixes,
            };
        }, firstQuadString);
    }
    evaluateQuad(quad, options) {
        const subject = this.evaluateTerm(quad.subject, options);
        const predicate = this.evaluateTerm(quad.predicate, options);
        const object = this.evaluateTerm(quad.object, options);
        const graph = this.evaluateTerm(quad.graph, options);
        return {
            value: `${subject.value} ${predicate.value} ${object.value} ${graph.value} .`,
            prefixes: [],
        };
    }
    evaluateLiteral(term) {
        return {
            value: ntriples.literal(term),
            prefixes: [],
        };
    }
    evaluateNamedNode(term) {
        return {
            value: ntriples.namedNode(term),
            prefixes: [],
        };
    }
    evaluateBlankNode(term) {
        return {
            value: ntriples.blankNode(term),
            prefixes: [],
        };
    }
    evaluateVariable() {
        throw new Error('N-Quads cannot serialize variables');
    }
    getFinalString(result) {
        return result;
    }
}
exports.NQuadsStrategy = NQuadsStrategy;
exports.nquads = (strings, ...values) => new TemplateResult_1.TemplateResult({
    strings,
    values,
    tag: exports.nquads,
    strategy: new NQuadsStrategy(),
    defaultOptions: {
        sortGraphs: false,
    },
});
