"use strict";
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const rdf_vocabularies_1 = require("@zazuko/rdf-vocabularies");
const TemplateResult_1 = require("./TemplateResult");
const turtleSyntax = __importStar(require("./syntax/turtle"));
function prefixDeclarations(prefixes) {
    return [...prefixes]
        .filter(prefix => prefix in rdf_vocabularies_1.prefixes)
        .map(prefix => `PREFIX ${prefix}: <${rdf_vocabularies_1.prefixes[prefix]}>`);
}
class SparqlStrategy extends TemplateResult_1.SerializationStrategy {
    evaluateLiteral(term, options) {
        return turtleSyntax.literal(term, options.base);
    }
    evaluateNamedNode(term, options) {
        return turtleSyntax.namedNode(term, options.base);
    }
    evaluateBlankNode(term) {
        return {
            value: turtleSyntax.blankNode(term),
            prefixes: [],
        };
    }
    evaluateVariable(term) {
        return {
            value: `?${term.value}`,
            prefixes: [],
        };
    }
    getFinalString(result, prefixes, options) {
        const prologue = options.prologue || typeof options.prologue === 'undefined';
        let prologueLines = [];
        if (prologue) {
            prologueLines = prefixDeclarations(prefixes);
            if (options.base) {
                prologueLines = [`BASE <${options.base}>`, ...prologueLines];
            }
            if (prologueLines.length > 0) {
                prologueLines.push('\n');
            }
        }
        return `${prologueLines.join('\n')}${result}`;
    }
    evaluateDataset() {
        throw new Error('Method not implemented');
    }
    evaluateQuad() {
        throw new Error('Method not implemented');
    }
}
exports.SparqlStrategy = SparqlStrategy;
exports.sparql = (strings, ...values) => new TemplateResult_1.TemplateResult({
    strings,
    values,
    tag: exports.sparql,
    strategy: new SparqlStrategy(),
    defaultOptions: {
        prologue: true,
    },
});
