"use strict";
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const rdf_vocabularies_1 = require("@zazuko/rdf-vocabularies");
const ntriples = __importStar(require("./ntriples"));
const xsd_1 = __importDefault(require("./xsd"));
function blankNode(term) {
    return ntriples.blankNode(term);
}
exports.blankNode = blankNode;
function namedNode(term, base = '') {
    const baseRegex = new RegExp('^' + base);
    const shrunk = rdf_vocabularies_1.shrink(term.value);
    if (shrunk) {
        return {
            value: shrunk,
            prefixes: [
                shrunk.split(':')[0],
            ],
        };
    }
    return {
        value: `<${term.value.replace(baseRegex, '')}>`,
        prefixes: [],
    };
}
exports.namedNode = namedNode;
function isBuiltInType(datatype) {
    return datatype.equals(xsd_1.default.integer) || datatype.equals(xsd_1.default.boolean) || datatype.equals(xsd_1.default.decimal);
}
function literal(term, base = '') {
    if (!term.language && term.datatype) {
        if (isBuiltInType(term.datatype)) {
            return {
                value: term.value,
                prefixes: [],
            };
        }
        if (!term.datatype.equals(xsd_1.default.string)) {
            const datatypeResult = namedNode(term.datatype, base);
            return {
                value: `"${term.value}"^^${datatypeResult.value}`,
                prefixes: datatypeResult.prefixes,
            };
        }
    }
    return {
        value: ntriples.literal(term),
        prefixes: [],
    };
}
exports.literal = literal;
